# Copyright (C) 2018  Lars Wirzenius
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import os
import shutil
import tempfile
import unittest


import ick2


class WorkspaceAreaTests(unittest.TestCase):

    def setUp(self):
        self.tempdir = tempfile.mkdtemp()
        self.area = ick2.WorkspaceArea()
        self.area.set_root(self.tempdir)

    def tearDown(self):
        shutil.rmtree(self.tempdir)

    def test_sets_root(self):
        self.assertEqual(self.area.get_root(), self.tempdir)

    def test_clears_workspace_area(self):
        name = 'foo-project'
        ws = self.area.create_workspace(name)
        self.area.clear()
        self.assertEqual(os.listdir(self.tempdir), [])

    def test_creates_workspace(self):
        name = 'foo-project'
        ws = self.area.create_workspace(name)
        self.assertTrue(isinstance(ws, ick2.Workspace))
        dirname = os.path.join(self.tempdir, name)
        self.assertEqual(ws.get_directory(), dirname)
        self.assertTrue(os.path.isdir(dirname))

    def test_creates_workspace_twice(self):
        name = 'foo-project'
        ws0 = self.area.create_workspace(name)
        ws = self.area.create_workspace(name)
        self.assertTrue(isinstance(ws, ick2.Workspace))
        dirname = os.path.join(self.tempdir, name)
        self.assertEqual(ws.get_directory(), dirname)
        self.assertTrue(os.path.isdir(dirname))

    def test_destroys_nonempty_workspace(self):
        name = 'foo-project'
        ws = self.area.create_workspace(name)
        dirname = ws.get_directory()
        with open(os.path.join(dirname, 'file.txt'), 'w') as f:
            f.write('hello, world')
        ws.destroy()
        self.assertFalse(os.path.exists(dirname))
